``xoutil.future.pprint`` - Extension to the data pretty printer
===============================================================

.. module:: xoutil.future.pprint

This modules includes all the Python's standard library features in module
`pprint`:mod: and adds the function `ppformat`:func:, which just returns a
string of the pretty-formatted object.

.. versionadded:: 1.4.1

.. autofunction:: ppformat
